package msdn.example.AndroidToAzure;

import android.app.Activity;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.Gallery;
import android.widget.ImageView;
import android.widget.Toast;


import java.net.HttpURLConnection; 
import java.net.URL;   
import java.util.ArrayList;

import javax.xml.parsers.DocumentBuilder; 
import javax.xml.parsers.DocumentBuilderFactory;   
import org.w3c.dom.Document; 
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import java.io.BufferedInputStream; 
import java.io.ByteArrayOutputStream; 
import java.io.InputStream; 
import java.io.IOException; 

public class AzureImageViewer extends Activity {
    public ArrayList<BlobInfo> BlobList= null;
    
    private Gallery mThumbnails;
    private ImageView mZoomView;
    
    //hardcoding the path to the URL; configuration UI is not part of the example
    public static final String AZURE_STORAGE_URL = "http://jofultz.blob.core.windows.net/filecabinet?comp=list";
    
	@Override
	public void onCreate(Bundle savedInstanceState) 
	{
		try{
			super.onCreate(savedInstanceState);  
			//Go ahead and get the blob list, because I need
			//info from it inside of the ImageAdapter
			InputStream blobstream = GetBlobs();
	
			//Get the objects from the XML returned
			DocumentBuilder docBuilder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
			Document doc = docBuilder.parse(blobstream);		BlobList = MarshalToBlobInfos(doc);
			
			//main layout code
	   	    setContentView(R.layout.main);    
		    mZoomView = (ImageView)findViewById(R.id.ZoomView);    
		    
		    mThumbnails = (Gallery) findViewById(R.id.Thumbnails);
		    mThumbnails.setAdapter(new ImageAdapter(this));
		    
		    mThumbnails.setOnItemClickListener(new OnItemClickListener()
		    {
		    	public void onItemClick (AdapterView<?> parent, View v, int position, long id)
		    	{
		    		BlobInfo CurrentBlob = BlobList.get(position);
		    		mZoomView.setImageBitmap(CurrentBlob.ImageBitmap);
		    	}
		    });
		}
        catch (Exception e) 
        { 
        	e.printStackTrace();      
        } 	
	}
	
	public ArrayList<BlobInfo> MarshalToBlobInfos(Document doc)
	{
		ArrayList<BlobInfo> returnBlobs = new ArrayList<BlobInfo>();
		
        try {
            Element root = doc.getDocumentElement();
            NodeList items = root.getElementsByTagName("Blob");
            for (int i=0;i<items.getLength();i++){
                BlobInfo blob = new BlobInfo();
                Node item = items.item(i);
                NodeList properties = item.getChildNodes();
                for (int j=0;j<properties.getLength();j++){
                    Node property = properties.item(j);
                    String name = property.getNodeName();
                    if (name.equalsIgnoreCase("Name")){
                        blob.Name = property.getFirstChild().getNodeValue();
                    } else if (name.equalsIgnoreCase("Url")){
                        blob.Url = property.getFirstChild().getNodeValue();
                    } else if (name.equalsIgnoreCase("Size")){
                        blob.Size = Long.parseLong(property.getFirstChild().getNodeValue());
                    } else if (name.equalsIgnoreCase("LastModified")){
                        blob.LastModified = property.getFirstChild().getNodeValue();
                    }
                }
                returnBlobs.add(blob);
            }
        } catch (Exception e) {
            throw new RuntimeException(e);
        } 

        return returnBlobs;
	}
	
	//   To make this work have to have INTERNET permission for the Android app
	//   <uses-permission android:name="android.permission.INTERNET" /> needs to be added to the manifest
	public InputStream GetBlobs()
	{
		HttpURLConnection uc;
		InputStream returnStream=null;
		
		try{
			//** Add code below if you have to deal with sockets **/
        	//SocketAddress proxySocket = new InetSocketAddress("[proxy]", [port]);
        	//Proxy proxy = new Proxy(Proxy.Type.HTTP, proxySocket);
        	URL u = new URL(AZURE_STORAGE_URL); 
        	uc = (HttpURLConnection) u.openConnection(); //u.openConnection(proxy);
 
        	uc.setRequestProperty("Accept", "*/*"); 
        	uc.setRequestProperty("Accept-Charset", "ISO-8859-1,utf-8;q=0.7,*;q=0.7");
        	uc.setRequestProperty("Accept-Language", "en-us,en;q=0.5"); 
        	uc.setRequestProperty("Keep-Alive", "300");     
        	uc.setRequestProperty("ucection", "keep-alive");    

        	returnStream = uc.getInputStream();

       	} 
        catch (Exception e) { 
        	e.printStackTrace();      
       	} 			
		
    	return returnStream;
	}

	//This method is no longer used in the example, but left it in for future use.
	public String readInputStreamAsString(InputStream InStream)      throws IOException 
	{      
		BufferedInputStream BufferedInStream = new BufferedInputStream(InStream);
		ByteArrayOutputStream BufferedOutStream = new ByteArrayOutputStream();     
		int result = BufferedInStream.read();     
		while(result != -1) 
		{       
			byte b = (byte)result;       
			BufferedOutStream.write(b);       
			result = BufferedInStream.read();     
		}             
		return BufferedOutStream.toString(); 
	} 
}
